@@ -1055,9 +1055,9 @@ Init_glib2(void)
     rb_define_const(RG_TARGET_NAMESPACE, "MAXSHORT", INT2FIX(G_MAXSHORT));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXUSHORT", UINT2NUM(G_MAXUSHORT));
 
-    rb_define_const(RG_TARGET_NAMESPACE, "MINLONG", INT2FIX(G_MINLONG));
-    rb_define_const(RG_TARGET_NAMESPACE, "MAXLONG", INT2NUM(G_MAXLONG));
-    rb_define_const(RG_TARGET_NAMESPACE, "MAXULONG", UINT2NUM(G_MAXULONG));
+    rb_define_const(RG_TARGET_NAMESPACE, "MINLONG", LL2NUM(G_MINLONG));
+    rb_define_const(RG_TARGET_NAMESPACE, "MAXLONG", LL2NUM(G_MAXLONG));
+    rb_define_const(RG_TARGET_NAMESPACE, "MAXULONG", ULL2NUM(G_MAXULONG));
 
     rb_define_const(RG_TARGET_NAMESPACE, "MININT8", INT2FIX(G_MININT8));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXINT8", INT2FIX(G_MAXINT8));
@@ -1071,16 +1071,16 @@ Init_glib2(void)
     rb_define_const(RG_TARGET_NAMESPACE, "MAXINT32", INT2NUM(G_MAXINT32));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXUINT32", UINT2NUM(G_MAXUINT32));
 
-    rb_define_const(RG_TARGET_NAMESPACE, "MININT64", INT2FIX(G_MININT64));
+    rb_define_const(RG_TARGET_NAMESPACE, "MININT64", LL2NUM(G_MININT64));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXINT64", LL2NUM(G_MAXINT64));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXUINT64", ULL2NUM(G_MAXUINT64));
 
-    rb_define_const(RG_TARGET_NAMESPACE, "MAXSIZE", UINT2NUM(G_MAXSIZE));
+    rb_define_const(RG_TARGET_NAMESPACE, "MAXSIZE", ULL2NUM(G_MAXSIZE));
 
-    rb_define_const(RG_TARGET_NAMESPACE, "MINFLOAT", INT2FIX(G_MINFLOAT));
+    rb_define_const(RG_TARGET_NAMESPACE, "MINFLOAT", DBL2NUM(G_MINFLOAT));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXFLOAT", DBL2NUM(G_MAXFLOAT));
 
-    rb_define_const(RG_TARGET_NAMESPACE, "MINDOUBLE", INT2FIX(G_MINDOUBLE));
+    rb_define_const(RG_TARGET_NAMESPACE, "MINDOUBLE", DBL2NUM(G_MINDOUBLE));
     rb_define_const(RG_TARGET_NAMESPACE, "MAXDOUBLE", DBL2NUM(G_MAXDOUBLE));
 
     /* Standard Macros */
@@ -1146,6 +1146,9 @@ union       GDoubleIEEE754;
     rb_define_const(RG_TARGET_NAMESPACE, "PRIORITY_LOW", INT2FIX(G_PRIORITY_LOW));
 
 /*    Init_mem(); */
+
+    Init_glib_gc();
+
     Init_gutil();
     Init_gutil_callback();
 
@@ -1162,6 +1165,7 @@ union       GDoubleIEEE754;
     Init_gobject();
 
     /* Require GBoxed/GObject */
+    Init_glib_error_conversions();
     Init_glib_utils();
     Init_glib_spawn();
     Init_glib_spawnerror();
